@@ -24,6 +24,14 @@ sub get_original_value {
     return $f->original_value;
 }
 
+sub get_post_filter_value {
+    my ($self, $key) = @_;
+
+    my $f = $self->get_field($key);
+    return undef unless defined($f);
+    return $f->post_filter_value;
+}
+
 sub get_value {
     my ($self, $key) = @_;
 
@@ -191,6 +199,10 @@ Deletes the specified value from the results.
 
 Get the original value for the specified field.
 
+=head2 get_post_filter_value ($name)
+
+Get the post-filter value for the specified field.
+
 =head2 get_value ($name)
 
 Returns the value for the specified field.  The value may be different from
